unit SQLExec;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, RXSplit, Grids, DBGrids, DB, DBTables,
  Placemnt, Buttons,Strings,PrpEdtrs,DsgnIntf;

type
  T_dlgSql = class(TForm)
    pnlTop: TPanel;
    pnlRun: TPanel;
    memSql: TMemo;
    Query: TQuery;
    dsQuery: TDataSource;
    DBGrid: TDBGrid;
    RxSplitter1: TRxSplitter;
    FormStorage: TFormStorage;
    StatusBar: TPanel;
    Label1: TLabel;
    cbAlias: TComboBox;
    Panel1: TPanel;
    SpeedButton1: TSpeedButton;
    procedure SQLRun(Sender: TObject);
    procedure ClearCaption(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure cbAliasChange(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    FIsActive     : boolean;
  public
    { Public declarations }
    property IsActive : Boolean read FIsActive default False;
  end;

 TSQLExecDialog = class(TComponent)
  private
    { Private declarations }
    FDatabaseName : TFileName;
    FIniFileName  : String;
    FWinHeight    : Integer;
    FWinWidth     : Integer;
    FWinTop       : Integer;
    FWinLeft      : Integer;
    FDialog       : T_dlgSql;
    FFormStyle    : TFormStyle;
    FModal        : boolean;
    procedure SetDatabaseName(const Value: TFileName);
  protected
    { Protected declarations }
  public
    { Public declarations }
    procedure Execute;
    constructor Create(AOwner: TComponent); override;
    destructor Free;
  published
    { Published declarations }
    property DatabaseName : TFileName  read FDatabaseName write SetDatabaseName;
    property IniFileName  : String     read FIniFileName  write FIniFileName;
    property WinHeight    : Integer    read FWinHeight    write FWinHeight;
    property WinWidth     : Integer    read FWinWidth     write FWinWidth;
    property WinTop       : Integer    read FWinTop       write FWinTop;
    property WinLeft      : Integer    read FWinLeft      write FWinLeft;
    property FormStyle    : TFormStyle read FFormStyle    write FFormStyle default fsStayOnTop;
    property Modal        : boolean    read FModal        write FModal default false;
  end;


procedure Register;

implementation

{$R *.DFM}

{-------------------}
procedure Register;
begin
  RegisterComponents('Dialogs', [TSQLExecDialog]);
  RegisterPropertyEditor(TypeInfo(TFileName), TSQLExecDialog, 'DatabaseName', TDatabaseNameProperty);
end;

{========  TformSql  ==========}

procedure T_dlgSql.SQLRun(Sender: TObject);
begin
 if Query.Active then Query.Close;
 Query.SQL.Assign(memSql.Lines);
 StatusBar.Caption := 'SQL Running...';
 StatusBar.Update;
 Screen.Cursor := crSQLWait;
 try
  try
   Query.Open;
  except
   Query.ExecSQL;
  end;
 except on E: Exception do
  begin
   Screen.Cursor := crDefault;
   StatusBar.Caption := 'SQL Error ' + E.Message;
   Exit;
  end;
 end;
 Screen.Cursor := crDefault;
 StatusBar.Caption := 'SQL Executed';
end;

procedure T_dlgSql.ClearCaption(Sender: TObject);
begin
 StatusBar.Caption := '';
 FIsActive := True;
end;

procedure T_dlgSql.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if Key = VK_F9 then SQLRun(Sender);
  if Key = VK_ESCAPE then Close;
end;

procedure T_dlgSql.cbAliasChange(Sender: TObject);
begin
 if Query.Active then Query.Close;
 Query.DatabaseName := (Sender As TComboBox).Text;;
end;


{===========  TSQLExecDialog  ==========}

constructor TSQLExecDialog.Create(AOwner: TComponent);
begin
 inherited Create(AOwner);
 WinHeight := 300;
 WinWidth  := 450;
 WinTop    := 100;
 WinLeft   := 200;
 FDialog := nil;
 FFormStyle := fsStayOnTop;
 FModal := false;
 IniFileName := '';
end;

destructor TSQLExecDialog.Free;
begin
 if FDialog <> nil then
 try
  FDialog.Free;
 finally
 end;
end;

procedure TSQLExecDialog.Execute;
begin
 if FDialog = nil
 then FDialog := T_dlgSQL.Create(Self);
 if FDialog.IsActive then Exit;
 with FDialog do
 begin
  Query.Close;
  Query.DatabaseName := DatabaseName;
  Session.GetAliasNames(cbAlias.Items);
  cbAlias.ItemIndex := cbAlias.Items.IndexOf(DatabaseName);
  Height := WinHeight;
  Width  := WinWidth;
  Top    := WinTop;
  Left   := WinLeft;
  if Trim(IniFileName) <> '' then
  begin
   FormStorage.IniFileName := IniFileName;
   FormStorage.Active := True;
  end;
  FormStyle := FFormStyle;
  if FModal
  then begin
   ShowModal;
   {Free;}
  end
  else Show;
 end;

end;

procedure TSQLExecDialog.SetDatabaseName(const Value: TFileName);
begin
  if FDatabaseName <> Value then
    FDatabaseName := Value;
end;

procedure T_dlgSql.FormClose(Sender: TObject; var Action: TCloseAction);
begin
 FIsActive := False;
end;

procedure T_dlgSql.FormCreate(Sender: TObject);
begin
 FIsActive := False;
end;

end.
